@@ -22,6 +22,7 @@ use XML::NewsML_G2::Audio;
 use XML::NewsML_G2::Icon;
 use XML::NewsML_G2::Topic;
 use XML::NewsML_G2::Product;
+use XML::NewsML_G2::Link;
 use XML::NewsML_G2::Package_Item;
 use XML::NewsML_G2::Group;
 use XML::NewsML_G2::Scheme_Manager;
@@ -33,7 +34,7 @@ use XML::NewsML_G2::Writer::News_Message;
 use warnings;
 use strict;
 
-use version; our $VERSION = qv('0.2.4');
+use version; our $VERSION = qv('0.2.6');
 
 1;
 
@@ -46,7 +47,7 @@ XML::NewsML_G2 - generate NewsML-G2 news items
 
 =head1 VERSION
 
-0.2.4
+0.2.6
 
 =begin readme
 
@@ -254,6 +255,8 @@ and the inline catalog will be replaced with a link:
 
 =item L<XML::NewsML_G2::Icon>
 
+=item L<XML::NewsML_G2::Link>
+
 =back
 
 
@@ -361,7 +364,7 @@ upcoming release.
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2013-2014, APA-IT. All rights reserved.
+Copyright (c) 2013-2015, APA-IT. All rights reserved.
 
 This module is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
