@@ -7,6 +7,7 @@ with 'XML::NewsML_G2::Role::HasQCode';
 
 has 'notice', isa => 'Str', is => 'ro';
 has 'uri', isa => 'Str', is => 'ro';
+has '+qcode', required => 0;
 
 __PACKAGE__->meta->make_immutable;
 
@@ -33,6 +34,10 @@ for an optional copyright notice
 
 optional uri to copyright holder
 
+=item qcode
+
+optional qcode of the copyright holder
+
 =back
 
 =head1 AUTHOR
