@@ -120,6 +120,18 @@ sub _create_catalogs {
 sub _create_item_meta_title {
 }
 
+sub _create_teaser {
+     my ($self, $cm) = @_;
+
+     if ($self->news_item->teaser) {
+         $cm->appendChild(
+             my $teaser = $self->create_element(
+                 'description', _text => $self->news_item->teaser));
+         $self->scheme_manager->add_role($teaser, 'drol', 'teaser');
+     }
+     return;
+}
+
 sub _create_item_meta {
     my ($self, $root) = @_;
 
@@ -169,7 +181,19 @@ sub _create_item_meta {
         $self->scheme_manager->add_qcode($s, 'ind', lc);
     }
 
-    $im->appendChild($self->create_element('link', rel => 'irel:seeAlso', residref => $self->_root_item->see_also)) if ($self->_root_item->see_also);
+    foreach my $attr (qw(see_also derived_from)) {
+        if ($self->_root_item->$attr) {
+            my $v = $self->_root_item->$attr;
+            (my $rel = $attr) =~ s/_(\w)/uc $1/ge;
+            my $linkelem = $self->create_element(
+                'link',
+                rel => "irel:$rel",
+                residref => $v->residref,
+                version => $v->version
+                );
+            $im->appendChild($linkelem);
+        }
+    }
 
     $root->appendChild($im);
     return;
@@ -203,7 +227,7 @@ sub create_element {
     if ($text) {
         $elem->appendChild($self->doc->createTextNode($text));
     } elsif ($name_text) {
-        $name_text = $name_text->name if $name_text->can('name');
+        $name_text = $name_text->name if (ref $name_text and $name_text->can('name'));
         $elem->appendChild($self->create_element('name', _text => $name_text));
     }
     return $elem;
