@@ -1,6 +1,7 @@
 package XML::NewsML_G2::Writer::News_Item;
 
 use Moose;
+use namespace::autoclean;
 
 extends 'XML::NewsML_G2::Writer';
 
@@ -19,8 +20,10 @@ sub _create_rights_info {
     my $ri = $self->create_element('rightsInfo');
 
     $ri->appendChild (my $crh = $self->create_element('copyrightHolder', _name_text => $self->news_item->copyright_holder));
-    $self->scheme_manager->add_qcode_or_literal($crh, 'copyright_holder', $self->news_item->copyright_holder->qcode);
     $crh->setAttribute('uri', $self->news_item->copyright_holder->uri) if $self->news_item->copyright_holder->uri;
+    if (my $qcode = $self->news_item->copyright_holder->qcode) {
+        $self->scheme_manager->add_qcode_or_literal($crh, 'copyright_holder', $qcode);
+    }
 
     my $notice = $self->news_item->copyright_holder->notice;
     $ri->appendChild($self->create_element('copyrightNotice', _text => $notice)) if $notice;
@@ -46,7 +49,7 @@ sub _create_subjects_desk {
     my @res;
 
     push @res, $self->doc->createComment('desks') if $self->news_item->has_desks;
-    foreach (@{$self->news_item->desks}) {
+    foreach (sort {$a->qcode cmp $b->qcode} @{$self->news_item->desks}) {
         push @res, my $s = $self->create_element('subject', type => 'cpnat:abstract', _name_text => $_);
         $self->scheme_manager->add_qcode_or_literal($s, 'desk', $_->qcode);
     }
@@ -193,11 +196,31 @@ sub _create_asserts_organisation {
     return @res;
 }
 
+sub _create_asserts_location {
+    my $self = shift;
+    my @res;
+
+    foreach my $loc_k (sort keys %{$self->news_item->locations}) {
+        my $location = $self->news_item->locations->{$loc_k};
+        next unless (defined $location->longitude && defined $location->latitude);
+        push @res, my $l = $self->create_element('assert');
+        $self->scheme_manager->add_qcode_or_literal($l, 'geo', $location->qcode);
+
+        $l->appendChild(my $geo_area_details = $self->create_element('geoAreaDetails'));
+        $geo_area_details->appendChild(my $pos = $self->create_element('position'));
+
+        $pos->setAttribute($_, $location->$_) for qw/latitude longitude/;
+    }
+
+    return @res;
+}
+
 sub _create_asserts {
     my $self = shift;
     my @res;
 
     push @res, $self->_create_asserts_organisation();
+    push @res, $self->_create_asserts_location();
 
     return @res;
 }
@@ -284,6 +307,13 @@ sub _create_content_meta {
         $self->scheme_manager->add_role($desc, 'drol', 'caption');
     }
 
+    if ($self->news_item->summary) {
+        $cm->appendChild(my $smry = $self->create_element('description', _text => $self->news_item->summary));
+        $self->scheme_manager->add_role($smry, 'drol', 'summary');
+    }
+
+    $self->_create_teaser($cm);
+
     $root->appendChild($cm);
 
     my @asserts = $self->_create_asserts();
@@ -291,6 +321,7 @@ sub _create_content_meta {
     return;
 }
 
+
 sub _create_content {
     my ($self, $root) = @_;
 
